@@ -761,6 +761,6 @@ void
 aerror(Area UNUSED(*ap), const char *msg)
 {
 	internal_errorf(1, "alloc: %s", msg);
-	errorf(null); /* this is never executed - keeps gcc quiet */
+	errorf(NULL); /* this is never executed - keeps gcc quiet */
 	/*NOTREACHED*/
 }
